@@ -56,8 +56,9 @@
 #include <QStyleFactory>
 #include <QFormLayout>
 #include <QStandardItemModel>
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QStyle>
-#include <QtDBus/QtDBus>
 
 #include <KGlobal>
 #include <KGlobalSettings>
@@ -73,6 +74,7 @@
 #endif
 
 // X11 namespace cleanup
+#undef Bool
 #undef Below
 #undef KeyPress
 #undef KeyRelease
@@ -122,7 +124,7 @@ public:
         }
     }
 
-    bool eventFilter( QObject* /* obj */, QEvent* ev ) Q_DECL_OVERRIDE
+    bool eventFilter( QObject* /* obj */, QEvent* ev ) override
     {
         switch( ev->type() )
         {
@@ -209,7 +211,7 @@ KCMStyle::KCMStyle( QWidget* parent, const QVariantList& )
     hbLayout->setStretchFactor( cbStyle, 1 );
     label->setBuddy(cbStyle);
 
-    pbConfigStyle = new QPushButton( QIcon::fromTheme(QStringLiteral("configure")), i18n("Con&figure..."), gbWidgetStyle );
+    pbConfigStyle = new QPushButton( i18n("Con&figure..."), gbWidgetStyle );
     pbConfigStyle->setEnabled( false );
     hbLayout->addWidget( pbConfigStyle );
 
