@@ -25,19 +25,19 @@
 
 #include "knetattach.h"
 
-int main(int argc, char **argv) {
+int main(int argc, char **argv)
+{
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("knetattach5");
 
 	KAboutData aboutData(QLatin1String("knetattach"), i18n("KDE Network Wizard"), PROJECT_VERSION, i18n("KDE Network Wizard"),KAboutLicense::GPL, i18n("(c) 2004 George Staikos"), QLatin1String("http://www.kde.org/"));
 
-	aboutData.addAuthor(i18n("George Staikos"), i18n("Primary author and maintainer"), "staikos@kde.org");
+    aboutData.addAuthor(i18n("George Staikos"), i18n("Primary author and maintainer"), QStringLiteral("staikos@kde.org"));
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    //PORTING SCRIPT: adapt aboutdata variable if necessary
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
